from .AbstractReader import AbstractReader
from PIL import Image
from pytesseract import pytesseract


class ImageReader(AbstractReader):

    IMAGE_TYPES = ['jpg', 'jpeg', 'png']

    __lang = 'eng'

    @staticmethod
    def set_language(lang):
        ImageReader.__lang = lang

    @classmethod
    def load_file(cls, file_path):
        cls.file = Image.open(file_path)

    @classmethod
    def to_string(cls):
        return pytesseract.image_to_string(cls.file, lang=ImageReader.__lang)



from .AbstractReader import AbstractReader
from pdfminer import high_level


class PdfReader(AbstractReader):

    @classmethod
    def load_file(cls, file_path):
        cls.file = file_path

    @classmethod
    def to_string(cls):
        return high_level.extract_text(pdf_file=cls.file)




from abc import ABC, abstractmethod


class AbstractReader(ABC):

    def __init__(self):
        self.__file = None

    @classmethod
    @abstractmethod
    def load_file(cls, file_path):
        pass

    @classmethod
    @abstractmethod
    def to_string(cls):
        pass

    @property
    def file(self):
        return self.__file

    @file.setter
    def file(self, value):
        self.__file = value



import os


def get_extension_file(file_path: str) -> str:
    return file_path.split('.')[-1].lower()


def create_folder(folder_path: str):

    if not os.path.isdir(folder_path):
        try:
            os.mkdir(folder_path)
        except OSError:
            raise Exception('failed to create directory')


def to_txt(text_raw: str, file_name: str, out_path: str):

    with open(f'{out_path}/{file_name}.txt', "w") as output:
        output.write(text_raw)
        output.close()




from .AbstractReader import AbstractReader
from docx2txt import docx2txt


class DocxReader(AbstractReader):

    @classmethod
    def load_file(cls, file_path):
        cls.file = file_path

    @classmethod
    def to_string(cls):
        return docx2txt.process(cls.file)
